//
// file: plotSingleHistogram.C
//
// macros:
//   plotHistogram  - plots a single histogram and saves it to a eps file.
//   CreateNewHisto - helper macro to add histograms in different directories
//
//  Note that the destination directory has to be specified as a global variable
//  externally. That means the function "TString PlotTargetDir()" has to be defined 
//  elsewhere.
//
// Modifications:

//----------------------------------------------------------------------------
// 
// add histograms from different directories together.
TH1F *CreateNewHisto(TDirectory *d,TString name,TObjArray inHistos);

//----------------------------------------------------------------------------
// 
//
// plot a single histogram in this directory
int plotHistogram(const TObjArray& inDir,  // array containing directories from which to plot
		  const TString& name,     // name of the input histogram
		  const TString& xtitle,   // x-axis title
		  const TString& suffix=".eps", // output filename extension
		  int legendCorner=1,
		  int rebin=1,int smoothen=400,
		  float xmin=-99999.,float xmax=-1.,
		  float ymin=-99999.,float ymax=-1.)
{
 
  const float XSNorm=0.88/100000.;
 

  TString cname="histo_";
  cname+=name+PlotChoice();
  TCanvas *c1 = new TCanvas(cname.Data(), "",50,44,600,500);
  // make more space for the Y-axis title
  c1->SetLeftMargin( .21); // default is 10%
  c1->SetBottomMargin(0.15);


  TObjArray histos;

  // legends for the histograms
  TString legends[33]={"1000","1000 plus","1000 minus",
		       "0100","0100 plus","0100 minus",
		       "sim0100","sim0100 plus","sim0100 minus",
		       "0010","0010 plus","0010 minus",  
		       "sim0010","sim0010 plus","sim0010 minus",
		       "0001","0001 plus","0001 minus",
		       "sim0001","sim0001 plus","sim0001 minus",
                       "1100", "1100 plus", "1100 minus",
                       "1010", "1010 plus", "1010 minus",
		       "1001", "1001 plus", "1001 minus",
		       "2000", "2000 plus", "2000 minus"};
  if(PlotChoice().Contains("SM")) {
    legends[3]="SM";
    legends[4]="SM plus";
    legends[5]="SM minus";
  }
  if(PlotChoice().Contains("FL1FR1sum")) {
    legends[3]="1000+0100";
    legends[4]="1000+0100 plus";
    legends[5]="1000+0100 minus";
  }
  if(PlotChoice().Contains("FL1FL2sum")) {
    legends[9]="1000+0010";
    legends[10]="1000+0010 plus";
    legends[11]="1000+0010 minus";
  }
  if(PlotChoice().Contains("FL1FR2sum")) {
    legends[15]="1000+0001";
    legends[16]="1000+0001 plus";
    legends[17]="1000+0001 minus";
  }
  
  Int_t palette[21]={1,2,4, 2,1,4, 4,1,2, 3,1,2, 37,1,2, 1,2,4};
  Int_t styles[21]= {1,2,3, 2,1,3, 3,1,2, 4,1,2,  1,2,3, 1,2,3};
 

  Int_t nPlots=0;
  Int_t plotID[21];
  int drawLine=0;       // draw histograms, no line
  bool normalize=false;

  TDirectory *td,*td1;
  //
  // grab the histograms
  //
  TObjArray tempHistos;
  TObject *tempo;
  TH1F *temphist,*tht;
  
  for(int iF=0;iF<inDir.GetEntries();iF++) {
    td=(TDirectory*) inDir[iF];
    //cout<<" iF "<<iF<<" has title "<<td->GetTitle()<<endl;
    if(td==0 || td->GetTitle()==TString("NULL")) {
      // if the directory doesn't exist, add a bunch of
      // dummy histograms
      tempHistos.Add(0);
      tempHistos.Add(0);
      tempHistos.Add(0);
      continue;
    }
    td1=(TDirectory*) td->Get("inclusive");
    tempo = td1->Get(name.Data());
    if(tempo==0) {
      cout<<"Error in plotHistogram: null pointer for inclusive histogram in file "<<iF<<endl;
      tempHistos.Add(0);
    }
    else tempHistos.Add(tempo);
    td1=(TDirectory*) td->Get("plusCharge");
    tempo = td1->Get(name.Data());
    if(tempo==0) {
      cout<<"Error in plotHistogram: null pointer for plusCharge histogram in file "<<iF<<endl;
      tempHistos.Add(0);
    }
    else tempHistos.Add(tempo);
    td1=(TDirectory*) td->Get("minusCharge");
    tempo = td1->Get(name.Data());
    if(tempo==0) {
      cout<<"Error in plotHistogram: null pointer for minusCharge histogram in file "<<iF<<endl;
      tempHistos.Add(0);
    }
    else tempHistos.Add(tempo);
    //
    //cout<<"Histogram title "<<tempo->GetTitle()<<endl;
  }
 
  nPlots=0;
  // choose what to display based on the input parameter
  if(PlotChoice()=="all") {
    nPlots=5;
    plotID[0]=0;
    plotID[1]=3;
    plotID[2]=6;
    plotID[3]=9;
    plotID[4]=12;
  }
  else if(PlotChoice()=="FR1") {
     nPlots=2;
     plotID[0]=0;
     plotID[1]=3;
  }
  else if(PlotChoice()=="FR1sim") {
    nPlots=3;
    plotID[0]=0;
    plotID[1]=3;
    plotID[2]=6;
  }
  else if(PlotChoice()=="FR1ratio") {
    nPlots=2;
    plotID[0]=0;
    plotID[1]=3;
    rebin=1;
  }
  else if(PlotChoice()=="FR1simratio") {
    nPlots=2;
    plotID[0]=3;
    plotID[1]=6;
    rebin=1;
  }
  else if(PlotChoice()=="FR1psim") {
    nPlots=3;
    plotID[0]=1;
    plotID[1]=4;
    plotID[2]=7;
  }
  else if(PlotChoice()=="FL1pm") {
    nPlots=2;
    plotID[0]=1;
    plotID[1]=2;
  }
  else if(PlotChoice()=="F1Rpm") {
    nPlots=2;
    plotID[0]=4;
    plotID[1]=5;
  }
  else if(PlotChoice()=="FL1pRp") {
    nPlots=2;
    plotID[0]=1;
    plotID[1]=4;
  }
  else if(PlotChoice()=="FL1pRm") {
    nPlots=2;
    plotID[0]=1;
    plotID[1]=5;
  }
  else if(PlotChoice()=="FL1SM") {
    nPlots=2;
    plotID[0]=0;
    plotID[1]=3;
  }
  else if(PlotChoice()=="SMFL1ratio") {
    nPlots=2;
    plotID[0]=3;
    plotID[1]=0;
    rebin=1;
  }
  else if(PlotChoice()=="F2") {
    nPlots=3;
    plotID[0]=0;
    plotID[1]=9;
    plotID[2]=15;
  }
  else if(PlotChoice()=="FL2") {
    nPlots=2;
    plotID[0]=0;
    plotID[1]=9;
  }
  else if(PlotChoice()=="FR2") {
    nPlots=2;
    plotID[0]=0;
    plotID[1]=15;
  }
  else if(PlotChoice()=="FL2sim") {
    nPlots=3;
    plotID[0]=0;
    plotID[1]=9;
    plotID[2]=12;
  }
  else if(PlotChoice()=="FR2sim") {
    nPlots=3;
    plotID[0]=0;
    plotID[1]=15;
    plotID[2]=18;
  }
  else if(PlotChoice()=="FL2ratio") {
    nPlots=2;
    plotID[0]=9;
    plotID[1]=0;
    rebin=1;
  }
  else if(PlotChoice()=="FL2simratio") {
    nPlots=2;
    plotID[0]=9;
    plotID[1]=12;
    //rebin=0;
  }
  else if(PlotChoice()=="FR2simratio") {
    nPlots=2;
    plotID[0]=15;
    plotID[1]=18;
    rebin=1;
  }
  else if(PlotChoice().Contains("FL1FR1sum")) {
    nPlots=3;
    plotID[0]=0;
    plotID[1]=3;
    plotID[2]=21;
    // also add the 0100 histogram to the 1000 one
    for(int i=0;i<3;i++) {
      temphist = (TH1F*) (tempHistos[i+3]);
      tht=(TH1F*) (tempHistos[i]);
      temphist->Add(tht);
      temphist->Scale(0.5);
    }
  }
  else if(PlotChoice().Contains("FL1FL2sum")) {
    nPlots=3;
    plotID[0]=0;
    plotID[1]=9;
    plotID[2]=24;
    // also add the third histogram to the first one
    for(int i=0;i<3;i++) {
      temphist = (TH1F*) (tempHistos[i+9]);
      tht=(TH1F*) (tempHistos[i]);
      temphist->Add(tht);
      temphist->Scale(0.5);
    }
  }
  else if(PlotChoice().Contains("FL1FR2sum")) {
    nPlots=3;
    plotID[0]=0;
    plotID[1]=15;
    plotID[2]=27;
    // also add the third histogram to the first one
    for(int i=0;i<3;i++) {
      temphist = (TH1F*) (tempHistos[i+15]);
      tht=(TH1F*) (tempHistos[i]);
      temphist->Add(tht);
      temphist->Scale(0.5);
    }
  }
  else if(PlotChoice().Contains("2FL1")) {
    nPlots=2;
    plotID[0]=0;
    plotID[1]=30;
    // also add the third histogram to the first one
    for(int i=0;i<3;i++) {
      temphist = (TH1F*) (tempHistos[i]);
      //temphist->Scale(2.);
    }
  }

  // make two different plots for 
  // and set up arrays for colors and palettes and legends
  Int_t ppalette[21];
  Int_t pstyles[21];
  TString plegends[21];

  for(int i=0;i<nPlots;i++) {
    int j=plotID[i];
    if(tempHistos[j]==0) {
      cout<<"Warning: histogram "<<j<<" is a null pointer, "<<legends[j]<<endl;
      continue;
    }
    temphist=(TH1F*) (tempHistos[j])->Clone();
    
    //cout<<"i "<<i<<", j "<<j<<", name "<<temphist->GetName()<<endl;
    // scale up by 1000 to get to fb
    double scalefactor=1000.*XSNorm;
    // scale down by bin width and rebin factor so that we get units of fb/GeV
    scalefactor*=1./((double) (temphist->GetBinWidth(1)));
    if(rebin>0) scalefactor*=1./((double) rebin);
    //cout<<"rebin is "<<rebin<<", width is "<<temphist->GetBinWidth(1)<<", scale factor "<<scalefactor<<endl;
    temphist->Scale(scalefactor);


    if(PlotChoice().Contains("ratio")) {
      temphist->Rebin(rebin);
      if(i==1) {
	TH1F* tht=(TH1F*) histos[0];
	tht->Divide(temphist);
	legends[0]="ratio";
	rebin=0;
      }
      else {
	// this is the denominator, simply add the histo to the list
	histos.Add(temphist);    
      }
    } // end of: if taking ratio
    else {
      // simply add the histo to the list
      histos.Add(temphist);    
    }
    
    ppalette[i]=palette[i];
    pstyles[i]=styles[i];
    plegends[i]=legends[j];
  }
 
  // change the y axis title in case the x axis title contains the sub-string []
  TString ytitle="#sigma [fb]";
  if(xtitle.Contains("[")) {
    int iBegin,iEnd;
    iBegin=xtitle.Index("[");
    iEnd=xtitle.Index("]");
    ytitle="#sigma [fb/"+xtitle(iBegin+1,iEnd-iBegin-1)+"]";
    //cout<<"found substr, extracting "<<xtitle(iBegin+1,iEnd-iBegin-1)<<endl;
  }
  CombineHistos(histos,plegends,name.Data(),xtitle.Data(),ytitle.Data(),ppalette,pstyles,legendCorner,smoothen,rebin,drawLine,normalize,xmin,xmax,-1.,ymin,ymax);
  
  // create the target directory if it doesn't exist:
  gSystem->mkdir(PlotTargetDir(),true);
  //cout<<"saving to file "<<PlotTargetDir()+"/"+cname+suffix<<endl;
  
  // and write the plot to file
  c1->SaveAs(PlotTargetDir()+"/"+cname+suffix);
  //cout<<"end of plotHistogram"<<endl;
  return 0;
} // end of plotHistogram

//---------------------------------------------------------------------------------------
//
// helper function to create a new histogram in a new directory, clone another histogram,
// and add in a bunch more histograms. Don't do any smoothing or rebinning here!
TH1F *CreateNewHisto(TDirectory *d,TString name,TObjArray inHistos)
{
  //  // start with one of the existing histograms
  TH1F *temph1=(TH1F*)inHistos[0];

  // now make the new directory
  td=(TDirectory*)d->Get(name.Data());
  if(td==NULL) td=d->mkdir(name.Data());
  td->cd();
  // and create the histogram here
  TH1F *finalHisto=temph1->Clone();
  // and now add in the other histograms we need
  TH1F* newHisto;
  for(int i=1;i<inHistos.GetEntries();i++) {
    temph1=(TH1F*)inHistos[i];
    newHisto=(TH1F*)temph1->Clone();
    // add
    finalHisto->Add(newHisto);
    delete newHisto;
  }
  return finalHisto;
}
