/******************************************************************************
 * CutElectron.hpp                                                            *
 *                                                                            *
 * Cuts on electron quantities                                                *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of CutElectron class                               *
 *    CutElectron()                     -- Parameterized Constructor          *
 *    ~CutElectron()                    -- Destructor                         *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Apply cuts and fill histograms     *
 *    GetCutName()                      -- Returns "CutElectron"              *
 *                                                                            *
 * Private Data Members of CutElectron class                                  *
 *    myTH1F* _hNJetsBefore              -- Hist of Num of jets before cuts   *
 *    myTH1F* _hNJetsAfter               -- Hist of Num of jets before cuts   *
 *    Int_t _ElectronPtMin;              -- Minimum Electron p_T              *
 *    Int_t _ElectronPtMax;              -- Maximum Electron p_T              *
 *                                                                            *
 * History                                                                    *
 *      13 Nov 2006 - Created by P. Ryan                                      *
 *****************************************************************************/

#ifndef CutElectron_h
#define CutElectron_h

#include "single_top_analysis/HistoCut.hpp"
#include "single_top_analysis/EventContainer.hpp"

#include <string>
#include <vector>
#include <sstream>

using namespace std;

class CutElectron : public HistoCut 
{

public:

  // Parameterized Constructor
  CutElectron(EventContainer *EventContainerObj);
  
  // Destructor
  ~CutElectron();

  // Get the name of describing the cut
  inline std::string GetCutName() { return "CutElectron"; };

  // Book Histograms
  void BookHistogram();

  // Apply cut and fill histogram
  Bool_t Apply();


private:

  // Histograms
  myTH1F* _hElectronNumberBefore;  // Histogram Electron Number before the cut
  myTH1F* _hElectronNumberAfter;   // Histogram Electron Number of jets after the cut

  myTH1F* _hElectronPtBefore;      // Histogram Electron p_T before the cut
  myTH1F* _hElectronPtAfter;       // Histogram Electron p_T of jets after the cut

  // Cut parameters
  Int_t _ElectronNumberMin;        // Minimum Electron Number
  Int_t _ElectronNumberMax;        // Maximum Electron Number

  Int_t _ElectronPtMin;            // Minimum Electron p_T
  Int_t _ElectronPtMax;            // Maximum Electron p_T

};


#endif







