///////////////////////////////////////////////////////////////////////////
// header file: MCElectron
// 
// Description: 
//  store information about final state MCelectrons
//
// Author: Reinhard Schwienhorst
// Date: 11/15/2006
//
// Modifications:
//
//
////////////////////////////////////////////////////////////////////////////
#ifndef MCelectron_h
#define MCelectron_h

#include "single_top_analysis/MCParticle.hpp"
#include "single_top_analysis/TruthTree.hpp"
//

class MCElectron: public MCParticle
{
 public:
  // default constructor
  MCElectron();
  // default constructor
  MCElectron(const MCElectron& other);

  // constructor with existing MC particle
  MCElectron(const MCParticle& other);

  //destructor
  ~MCElectron();

  // clear: set all contents to their defaults
  inline void Clear() { MCParticle::Clear(); _EoverP=0.; };

  // Fill the MCelectron from a TruthTree
  void Fill(TruthTree *trtr,int iE);

  // Setters
  // Set E over P for this MCelectron
  void SetEoverP(const double& eop) { _EoverP=eop; };

  // Getters
  double GetEoverP() const { return _EoverP; };
  double EoverP() const { return _EoverP; };


  // overloaded operators:
  // +=
  MCElectron& operator+=(const MCElectron& other);
  // addition:
  MCElectron operator+(const MCElectron& other);
  // overloaded assignment operator:
  MCElectron& operator=(const MCParticle& other);
  // overloaded assignment operator:
  MCElectron& operator=(const MCElectron& other);
  // overloaded assignment operator:
  MCElectron& operator=(MCElectron& other);
    

 private:
  double _EoverP;   // calo energy of the MCelectron divided by track momentum

  ////////////////////////////////////////
  // needed to run with Root:
  ClassDef(MCElectron,0)
};


#endif
