///////////////////////////////////////////////////////////////////////////
// header file: MCParticle
// 
// Description: 
//  store information about final state MC particles
//
// Author: Reinhard Schwienhorst
// Date: 11/15/2006
//
// Modifications:
//
//
////////////////////////////////////////////////////////////////////////////
#ifndef MCparticle_h
#define MCparticle_h

#include "single_top_analysis/Particle.hpp"
#include "single_top_analysis/TruthTree.hpp"
//

class MCParticle: public Particle
{
 public:
  // default constructor
  MCParticle();
  // default constructor
  MCParticle(const MCParticle& other);

  // constructor with existing particle
  MCParticle(const Particle& other);

  //destructor
  ~MCParticle();

  // clear: set all contents to their defaults
  inline void Clear() { Particle::Clear(); _PdgId=0; _Status=0; _BarCode=0; };

  // Fill the MCparticle from a TruthTree
  void Fill(TruthTree *trtr,int iE);

  // Setters
  // Set the pdgID for this MCparticle
  void SetPdgId(Int_t val) { _PdgId=val; };
  // Set the Status flag for this MCparticle
  void SetStatus(Int_t val) { _Status=val; };
  // Set the BarCode flag for this MCparticle
  void SetBarCode(Int_t val) { _BarCode=val; };

  // Getters
  // pdgID
  Int_t GetPdgId() const { return _PdgId; };
  Int_t PdgId() const { return GetPdgId(); };
  Int_t GetAbsPdgId() const { return(_PdgId>0 ? _PdgId : -_PdgId) ; };
  Int_t AbsPdgId() const { return GetAbsPdgId(); };
  // Status flag
  Int_t GetStatus() const { return _Status; };
  Int_t Status() const { return GetStatus(); };
  // stable flag
  Int_t GetBarCode() const { return _BarCode; };
  Int_t BarCode() const { return GetBarCode(); };


  // overloaded operators:
  // +=
  MCParticle& operator+=(const MCParticle& other);
  // addition:
  MCParticle operator+(const MCParticle& other);
  // overloaded assignment operator:
  MCParticle& operator=(const Particle& other);
  // overloaded assignment operator:
  MCParticle& operator=(const MCParticle& other);
  // overloaded assignment operator:
  MCParticle& operator=(MCParticle& other);
    

 private:
  Int_t _PdgId;    // PDG ID for this particle
  Int_t _Status;   // Status flag for this particle
  Int_t _BarCode;   // BarCode flag for this particle

  ////////////////////////////////////////
  // needed to run with Root:
  ClassDef(MCParticle,0)
};


#endif
