///////////////////////////////////////////////////////////////////////////
// header file: Muon
// 
// Description: 
//  store information about final state muons
//
// Author: Reinhard Schwienhorst
// Date: 11/14/2006
//
// Modifications:
//
//
////////////////////////////////////////////////////////////////////////////
#ifndef muon_h
#define muon_h

#include "single_top_analysis/Particle.hpp"
#include "single_top_analysis/EventTree.hpp"
//

class Muon: public Particle
{
 public:
  // default constructor
  Muon();
  // default constructor
  Muon(const Muon& other);

  // constructor with existing particle
  Muon(const Particle& other);

  //destructor
  ~Muon();

  // clear: set all contents to their defaults
  inline void Clear() { Particle::Clear(); _EtCone=0.; };

  // Fill the electron from an EventTree
  void Fill(EventTree *evtr,int iE);

  // Setters
  // Set cone Et for this muon
  void SetEtCone(const double& val) { _EtCone=val; };

  // Getters
  double GetEtCone() const { return _EtCone; };
  double EtCone() const { return _EtCone; };


  // overloaded operators:
  // +=
  Muon& operator+=(const Muon& other);
  // addition:
  Muon operator+(const Muon& other);
  // overloaded assignment operator:
  Muon& operator=(const Particle& other);
  // overloaded assignment operator:
  Muon& operator=(const Muon& other);
  // overloaded assignment operator:
  Muon& operator=(Muon& other);
    

 private:
  double _EtCone;   // calo energy in a cone around the muon

  ////////////////////////////////////////
  // needed to run with Root:
  ClassDef(Muon,0)
};


#endif
