///////////////////////////////////////////////////////////////////////////
// header file: Tau
// 
// Description: 
//  store information about final state taus
//
// Author: Reinhard Schwienhorst
// Date: 10/19/2006
//
// Modifications:
//
//
////////////////////////////////////////////////////////////////////////////
#ifndef tau_h
#define tau_h

#include "single_top_analysis/Particle.hpp"
#include "single_top_analysis/EventTree.hpp"
//

class Tau: public Particle
{
 public:
  // default constructor
  Tau();
  // default constructor
  Tau(const Tau& other);

  // constructor with existing particle
  Tau(const Particle& other);

  //destructor
  ~Tau();

  // clear: set all contents to their defaults
  inline void Clear() { Particle::Clear(); _NumTracks=0.; };

  // Fill the tau from an EventTree
  void Fill(EventTree *evtr,int iE);

  // Setters
  // Set E over P for this tau
  void SetNumTracks(const double& eop) { _NumTracks=eop; };

  // Getters
  double GetNumTracks() const { return _NumTracks; };
  double NumTracks() const { return _NumTracks; };


  // overloaded operators:
  // +=
  Tau& operator+=(const Tau& other);
  // addition:
  Tau operator+(const Tau& other);
  // overloaded assignment operator:
  Tau& operator=(const Particle& other);
  // overloaded assignment operator:
  Tau& operator=(const Tau& other);
  // overloaded assignment operator:
  Tau& operator=(Tau& other);
    

 private:
  double _NumTracks;   // number of tracks

  ////////////////////////////////////////
  // needed to run with Root:
  ClassDef(Tau,0)
};


#endif
