/******************************************************************************
 * HistogrammingNJets.cpp                                                     *
 *                                                                            *
 * Books and fills histograms                                                 *
 * Used for events passing cuts applied in other classes                      *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    HistogrammingNJets()              -- Parameterized Constructor          *
 *    ~HistogrammingNJets()             -- Destructor                         *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Fill histograms only (No Cuts)     *
 *    GetCutName()                      -- Returns "HistogrammingNJets"       *
 *                                                                            *
 * Private Data Members of AnalysisMain class                                 *
 *    myTH1F* _hNJets                   -- Hist of Num of jets                *
 *                                                                            *
 * History                                                                    *
 *      19 Oct 2006 - Created by R. Schwienhorst for ATLAS                    *
 *      10 Nov 2006 - Modified by P. Ryan - cleanup and reorganized           *
 *****************************************************************************/

#include "single_top_analysis/HistogrammingNJets.hpp"
#include<iostream>

using namespace std;

/******************************************************************************
 * HistogrammingNJets::NistogrammingNJets(EventContainer *obj)                     *
 *                                                                            *
 * Parameterized Constructor                                                  *
 *                                                                            *
 * Input:  Particle class                                                     *
 * Output: None                                                               *
 ******************************************************************************/
HistogrammingNJets::HistogrammingNJets(EventContainer *obj)
{
  SetEventContainer(obj);
} //HistogrammingNJets()

/******************************************************************************
 * HistogrammingNJets::~HistogrammingNJets()                                  *
 *                                                                            *
 * Destructor                                                                 *
 *                                                                            *
 * Input:  None                                                               *
 * Output: None                                                               *
 ******************************************************************************/
HistogrammingNJets::~HistogrammingNJets()
{
  
} //HistogrammingNJets

/******************************************************************************
 * void HistogrammingNJets::BookHistogram()                                          *
 *                                                                            *
 * Book Histograms                                                            *
 *                                                                            *
 * Input:  None                                                               *
 * Output: None                                                               *
 ******************************************************************************/
void HistogrammingNJets::BookHistogram(){
  
  // Histogram of Number of Jets
  _hNJets = DeclareTH1F("njets","Number of Jets",10,0.,10.);
  _hNJets->SetXAxisTitle("N_{Jets}");
  _hNJets->SetYAxisTitle("Events");
  // Jet 1 Pt
  _hPtJet1 = DeclareTH1F("PtJet1","Jet 1 PT",200,0.,400.);
  _hPtJet1->SetXAxisTitle("P_{T} (jet 1) [GeV]");
  _hPtJet1->SetYAxisTitle("Events");
  // Jet 2 Pt
  _hPtJet2 = DeclareTH1F("PtJet2","Jet 2 PT",200,0.,400.);
  _hPtJet2->SetXAxisTitle("P_{T} (jet 2) [GeV]");
  _hPtJet2->SetYAxisTitle("Events");
  // Jet 3 Pt
  _hPtJet3 = DeclareTH1F("PtJet3","Jet 3 PT",200,0.,400.);
  _hPtJet3->SetXAxisTitle("P_{T} (jet 3) [GeV]");
  _hPtJet3->SetYAxisTitle("Events");
  // Jet 4 Pt
  _hPtJet4 = DeclareTH1F("PtJet4","Jet 4 PT",200,0.,400.);
  _hPtJet4->SetXAxisTitle("P_{T} (jet 4) [GeV]");
  _hPtJet4->SetYAxisTitle("Events");
  //cout<<"end of HistogrammingNJets::BookHistogram"<<endl;

} //BookHistogram

/******************************************************************************
 * Bool_t HistogrammingNJets::Apply()                                         *
 *                                                                            *
 * Fill histograms                                                            *
 *                                                                            *
 * Input:  None                                                               *
 * Output: kTrue if successful                                                *
 ******************************************************************************/
Bool_t HistogrammingNJets::Apply()
{
  //cout<<"Begin of HistogrammingNJets::Apply()"<<endl;
  
  // Get Event Tree
  EventContainer *EventContainerObj = GetEventContainer();
  EventTree * evTree = EventContainerObj -> GetEventTree();
  
  // Fill Histograms
  _hNJets -> Fill(evTree -> PJet_N);

  if(evTree ->PJet_N>0) _hPtJet1 -> Fill(evTree -> PJet_p_T->operator[](0)/1000.);
  if(evTree ->PJet_N>1) _hPtJet2 -> Fill(evTree -> PJet_p_T->operator[](1)/1000.);
  if(evTree ->PJet_N>2) _hPtJet3 -> Fill(evTree -> PJet_p_T->operator[](2)/1000.);
  if(evTree ->PJet_N>3) _hPtJet4 -> Fill(evTree -> PJet_p_T->operator[](3)/1000.);

  //cout<<"End of HistogrammingNJets::Apply()"<<endl;
  return kTRUE;  
  
} //Apply












