//////////////////////////////////////////////////////////////////
//
// file: Taus.cpp
// Description: Create a container for an tau. 
//
// Author: Reinhard Schwienhorst
// Created: 11/14/2006
//
// Modifications:
//
//
//////////////////////////////////////////////////////////////////
#include "single_top_analysis/Tau.hpp"
#include <iostream>
#include <string>
#include <fstream>


using namespace std;

// needed to run with compiled Root:
ClassImp(Tau)

//-------------------------------------------------------------------------
// default constructor 
// 
  Tau::Tau() : Particle::Particle(),_NumTracks(0.)
{
}

//-------------------------------------------------------------------------
// default destructor 
// 
Tau::~Tau()
{
  //cout<<"In tau destructor"<<endl;
}

//-------------------------------------------------------------------------
// constructor from other tau 
// 
Tau::Tau(const Tau& other): Particle(other),_NumTracks(other.NumTracks())
{
}

//-------------------------------------------------------------------------
// constructor from other particle
// 
Tau::Tau(const Particle& other): Particle(other),_NumTracks(0.)
{
}

//-------------------------------------------------------------------------
// operator overloading
// 
// +=
Tau& Tau::operator+=(const Tau& other)
{
  
  Particle::operator+=(other);
  // also add NumTracks
  SetNumTracks(NumTracks()+other.NumTracks());
  return *this;
}

//-------------------------------------------------------------------------
// 
// addition operator overloading
Tau Tau::operator+(const Tau& other)
{
  //cout<<"beginning of  Tau::operator+"<<endl;
  Particle tltemp=Particle::operator+(other);
  Tau ptemp=tltemp;
  
  // I don't know how to add the NumTracks for two different taus.
  // For now, add them
  _NumTracks += other.NumTracks();
  ptemp.SetNumTracks( _NumTracks );

  // done! return the temp particle
  //cout<<"returning from  Tau::operator+"<<endl;
  return ptemp;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another tau
// 
Tau& Tau::operator=(const Particle& other)
{
  
  Particle::operator=(other);
  SetNumTracks(0.);
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another Tau
// (const version)
Tau& Tau::operator=(const Tau& other)
{
  
  Particle::operator=(other);
  SetNumTracks(other.NumTracks());
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another Tau
// (non-const version)
Tau& Tau::operator=(Tau& other)
{
  
  Particle::operator=(other);
  SetNumTracks(other.NumTracks());
  return *this;
}

//-------------------------------------------------------------------------
// initialize this tau from the event tree
// 
void Tau::Fill(EventTree *evtr,int iE)
{

    Double_t tauPt  = evtr->Tau_p_T->operator[](iE)/1000.;
    Double_t tauEta = evtr->Tau_eta->operator[](iE);
    Double_t tauPhi = evtr->Tau_phi->operator[](iE);
    Double_t tauE   = evtr->Tau_E->operator[](iE);
    _NumTracks      = evtr->Tau_numTrack->operator[](iE);
    Double_t tauCharge= evtr->Tau_charge->operator[](iE);

    SetPtEtaPhiE(tauPt,tauEta,tauPhi,tauE);
    SetCharge(tauCharge);

}


